---
name: Proposal
about: Suggest a large change for the Molecule project
labels: proposal
---


# Proposal: <proposal name>

*Author*: Your Name <@yourGitHufid> IRC: handle (if different)

*Date*: 2019-MM-DD

- Status: New
- Proposal type: (core design, process, ?)
- Estimated time to implement: <X days, weeks, etc.>


## Motivation

Describe the reasons for this proposal.

### Problems

What problems exist that this proposal will solve?
- Problem #1
- Problem #2
- Or just describe the problem if there is just one.

## Solution proposal

- Describe your suggested solution here.
- Insert code in snippets if you would like as shown.
```yaml
    - include: main.yml
      vars:
         var1: val1
```
- Be sure to explain how this solves problems.

## Dependencies (optional)

Explain any dependencies. This section is optional but could be helpful.
- Dependency #1
- Dependency #2

## Testing (optional)

Does / should this require testing, and if so, how? Describe here. This section is optional but could be helpful.

## Documentation (optional)

Does / should this require documentation? If so, describe here. This section is optional but could be helpful.

## Anything else?

If you'd like to add anything else beyond the above required and optional sections, you are welcome to do so.
